-- Copyright 1999-2024. WebPros International GmbH. All rights reserved.
-- vim:set ft=sql:
CREATE TABLE module_watchdog_param (
	param				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL PRIMARY KEY
,	val					VARCHAR(255) CHARACTER SET binary
) ENGINE=InnoDB;

CREATE TABLE module_watchdog_service (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	name				VARCHAR(63) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
,	label				VARCHAR(63) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
,   sort_val			SMALLINT UNSIGNED NOT NULL DEFAULT 65535
,	mon_status			ENUM ('monitored', 'notmonitored') NOT NULL DEFAULT 'notmonitored'
,	save_stats			ENUM ('on', 'off') NOT NULL DEFAULT 'on'
,	timeout				ENUM ('on', 'off') NOT NULL DEFAULT 'on'
,	timeout_restart_num	SMALLINT UNSIGNED NOT NULL DEFAULT 5
,	timeout_cycles_num	SMALLINT UNSIGNED NOT NULL DEFAULT 5
,	connection_timeout	SMALLINT UNSIGNED NOT NULL DEFAULT 5
,	start_cmd			VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
,	stop_cmd			VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
,	start_time			SMALLINT UNSIGNED NOT NULL DEFAULT 60

,						UNIQUE (name)
,						UNIQUE (label)
,						INDEX (name)
,						INDEX (sort_val)
) ENGINE=InnoDB;

CREATE TABLE module_watchdog_disk (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	device				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
,	space_rate			FLOAT UNSIGNED NOT NULL DEFAULT 80
,	space_rate_unit		ENUM('percent', 'gigabyte', 'megabyte', 'kilobyte') DEFAULT 'percent'
,	inods_rate			FLOAT UNSIGNED NOT NULL DEFAULT 80
,	inods_rate_unit		ENUM('percent', 'file') NOT NULL DEFAULT 'percent'
,	command				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin

,						UNIQUE (device)
) ENGINE=InnoDB;

CREATE TABLE module_watchdog_service_event (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	time				TIMESTAMP NOT NULL
,	service_id			INT UNSIGNED NOT NULL
,	name				ENUM ('NONWORK', 'RECOVER_WORK', 'TIMEOUT') NOT NULL

,						INDEX (time)
,						INDEX (service_id)
) ENGINE=InnoDB;

CREATE TABLE module_watchdog_disk_event (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	time				TIMESTAMP NOT NULL
,	device				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
,	name				ENUM ('RATE_EXCESS', 'BACK_TO_NORMAL', 'UNMOUNTED', 'MOUNTED')
,	mount_point			VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin
,	fs_size				INT UNSIGNED
,	used_size			INT UNSIGNED
,	inodes_num			INT UNSIGNED
,	used_inodes			INT UNSIGNED

,						INDEX (time)
,						INDEX (device)
) ENGINE=InnoDB;

CREATE TABLE module_watchdog_report (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	time				TIMESTAMP NOT NULL
,	name				VARCHAR(63) CHARACTER SET ascii COLLATE ascii_general_ci
,	type				ENUM ('SECUR_CHECK', 'PERIOD') NOT NULL

,						UNIQUE (name)
,						INDEX (type)
,						INDEX (time)
) ENGINE=InnoDB;

CREATE TABLE module_watchdog_sys_stat (
	time				TIMESTAMP NOT NULL
,	type				ENUM ('CPU_USAGE', 'MAINMEM_USAGE') NOT NULL
						-- CPU_USAGE - percent
						-- MAINMEM_USAGE - kilobytes
,	value				INT UNSIGNED NOT NULL
,	service_id			INT UNSIGNED

,						INDEX (time)
,						INDEX (type)
,						INDEX (service_id)
) ENGINE=InnoDB;

-- Inserting services.

INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('plesk_apache', 'Plesk Web Server', 10, '/bin/systemctl start sw-cp-server.service', '/bin/systemctl stop sw-cp-server.service');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('sw_engine', 'Plesk PHP Engine', 10, '/usr/local/psa/admin/sbin/pleskrc sw-engine start', '/usr/local/psa/admin/sbin/pleskrc sw-engine stop');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('apache', 'Web Server (Apache)', 20, '/usr/local/psa/admin/bin/websrvmng --start', '/usr/local/psa/admin/bin/websrvmng --stop');
INSERT INTO module_watchdog_service (name, label, sort_val, connection_timeout, start_cmd, stop_cmd) VALUES ('qmail', 'SMTP Server (Qmail)', 30, 60, '/usr/local/psa/admin/sbin/pleskrc qmail restart', '/usr/local/psa/admin/sbin/pleskrc qmail stop');
INSERT INTO module_watchdog_service (name, label, sort_val, connection_timeout, start_cmd, stop_cmd) VALUES ('postfix', 'SMTP Server (Postfix)', 30, 60, '/usr/local/psa/admin/sbin/pleskrc postfix restart', '/usr/local/psa/admin/sbin/pleskrc postfix stop');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('bind', 'DNS Server (BIND)', 50, '/usr/local/psa/admin/bin/dnsmng --restart', '/usr/local/psa/admin/bin/dnsmng --stop');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('docker', 'Docker', 50, '/usr/local/psa/admin/sbin/pleskrc docker start', '/usr/local/psa/admin/sbin/pleskrc docker stop');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('postgresql', 'PostgreSQL', 90, '/usr/local/psa/admin/bin/pg_manage --restart', '/usr/local/psa/admin/bin/pg_manage --stop');
INSERT INTO module_watchdog_service (name, label, sort_val, start_time, connection_timeout, start_cmd, stop_cmd) VALUES ('psa_spamassassin', 'Plesk SpamAssassin', 100, 120, 180, '/usr/local/psa/admin/bin/spammng --start', '/usr/local/psa/admin/bin/spammng --stop');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('drweb', 'Plesk Premium Antivirus', 110, '/usr/local/psa/admin/bin/drwebmng --start', '/usr/local/psa/admin/bin/drwebmng --stop');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('kavehost', 'Kaspersky Antivirus', 120, '/usr/local/psa/admin/bin/kavmng start', '/usr/local/psa/admin/bin/kavmng stop');
INSERT INTO module_watchdog_service (name, label, sort_val, connection_timeout, start_cmd, stop_cmd) VALUES ('pc_remote', 'Plesk Postfix milter filter', 130, 60, '/usr/local/psa/admin/bin/mailmng-service --start-service --mail-component=milter', '/usr/local/psa/admin/bin/mailmng-service --stop-service --mail-component=milter');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('nginx', 'Web Proxy Server (Nginx)', 130, '/usr/local/psa/admin/bin/nginx_control --start', '/usr/local/psa/admin/bin/nginx_control --stop');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('php_fpm', 'PHP-FPM (FastCGI Process Manager)', 140, '/usr/local/psa/admin/bin/phpinimng --type fpm --start --service-name php-fpm', '/usr/local/psa/admin/bin/phpinimng --type fpm --stop --service-name php-fpm');
INSERT INTO module_watchdog_service (name, label, sort_val, connection_timeout, start_cmd, stop_cmd) VALUES ('courier_imap', 'Courier IMAP server', 42, 60, '/usr/local/psa/admin/bin/mailmng-service --start-service --mail-component=imap', '/usr/local/psa/admin/bin/mailmng-service --stop-service --mail-component=imap');
INSERT INTO module_watchdog_service (name, label, sort_val, connection_timeout, start_cmd, stop_cmd) VALUES ('courier_imaps', 'Courier IMAP server with SSL/TLS support', 43, 60, '/usr/local/psa/admin/bin/mailmng-service --start-service --mail-component=imaps', '/usr/local/psa/admin/bin/mailmng-service --stop-service --mail-component=imaps');
INSERT INTO module_watchdog_service (name, label, sort_val, connection_timeout, start_cmd, stop_cmd) VALUES ('courier_pop3', 'Courier POP3 Server', 40, 60, '/usr/local/psa/admin/bin/mailmng-service --start-service --mail-component=pop3', '/usr/local/psa/admin/bin/mailmng-service --stop-service --mail-component=pop3');
INSERT INTO module_watchdog_service (name, label, sort_val, connection_timeout, start_cmd, stop_cmd) VALUES ('courier_pop3s', 'Courier POP3 Server with SSL/TLS support', 41, 60, '/usr/local/psa/admin/bin/mailmng-service --start-service --mail-component=pop3s', '/usr/local/psa/admin/bin/mailmng-service --stop-service --mail-component=pop3s');
INSERT INTO module_watchdog_service (name, label, sort_val, connection_timeout, start_cmd, stop_cmd) VALUES ('courier_authdaemon', 'Courier Authentication daemon', 45, 60, '/usr/local/psa/admin/bin/mailmng-service --start-service --mail-component=authdaemon', '/usr/local/psa/admin/bin/mailmng-service --stop-service --mail-component=authdaemon');

INSERT INTO module_watchdog_service (name, label, sort_val, connection_timeout, start_cmd, stop_cmd) VALUES ('dovecot', 'Dovecot IMAP and POP3 server', 46, 60, '/usr/local/psa/admin/bin/mailmng-service --start-service --mail-component=imap-pop3', '/usr/local/psa/admin/bin/mailmng-service --stop-service --mail-component=imap-pop3');

INSERT INTO module_watchdog_service (name, label, sort_val, connection_timeout, start_cmd, stop_cmd) VALUES ('fail2ban', 'Fail2Ban authentication failure monitor', 150, 60, '/usr/local/psa/admin/bin/f2bmng --start', '/usr/local/psa/admin/bin/f2bmng --stop');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('mysql_remote', 'Plesk database on a remote MySQL', 80, '', '');
INSERT INTO module_watchdog_service (name, label, sort_val, start_cmd, stop_cmd) VALUES ('mysql', 'Plesk database on a local MySQL', 80, '<mysql_init_script> start', '<mysql_init_script> stop');

-- Inserting initial values of parameters.

INSERT INTO module_watchdog_param VALUES ('locale', 'en-US');
INSERT INTO module_watchdog_param VALUES ('refresh_pages', 'on');
INSERT INTO module_watchdog_param VALUES ('automonit', 'on');
INSERT INTO module_watchdog_param VALUES ('poll_interval', 300);
INSERT INTO module_watchdog_param VALUES ('storage_sysstat', 'on');
INSERT INTO module_watchdog_param VALUES ('sysstat_storage_time', '365');
INSERT INTO module_watchdog_param VALUES ('secur_scan_rate', 'weekly'); -- none, daily, weekly, monthly
INSERT INTO module_watchdog_param VALUES ('report_rate', 'weekly'); -- none, daily, weekly, monthly
INSERT INTO module_watchdog_param SELECT 'email_to', val FROM misc WHERE param='admin_email' LIMIT 1;
INSERT INTO module_watchdog_param SELECT 'email_from', CONCAT('watchdog@', val) FROM misc WHERE param='FullHostName' LIMIT 1;
INSERT INTO module_watchdog_param VALUES ('mail_servers', 'localhost');

INSERT INTO module_watchdog_param VALUES ('configured', 'no');
INSERT INTO module_watchdog_param VALUES ('monitrc_tplfile', '/usr/local/psa/etc/modules/watchdog/monitrc.tpl');
INSERT INTO module_watchdog_param VALUES ('monitrc_chkfile', '/usr/local/psa/var/modules/watchdog/data/monitrc.chk');
INSERT INTO module_watchdog_param VALUES ('monitrc_file', '/usr/local/psa/etc/modules/watchdog/monitrc');
INSERT INTO module_watchdog_param VALUES ('monitrc_tplfile_include_dir', '/usr/local/psa/etc/modules/watchdog/service.tpl.d');
INSERT INTO module_watchdog_param VALUES ('monitrc_file_include_dir', '/usr/local/psa/etc/modules/watchdog/service.d');
INSERT INTO module_watchdog_param VALUES ('monit_pidfile', '/usr/local/psa/var/modules/watchdog/run/monit.pid');
INSERT INTO module_watchdog_param VALUES ('monit_tcp_port', 2911);
INSERT INTO module_watchdog_param VALUES ('monit_login', 'monit');
INSERT INTO module_watchdog_param VALUES ('monit_password', CONCAT(LEFT( MD5(RAND()), 14), 'a'));
INSERT INTO module_watchdog_param VALUES ('wdcollect_port', '2912');
INSERT INTO module_watchdog_param VALUES ('wdcollect_cfgfile', '/usr/local/psa/etc/modules/watchdog/wdcollect.inc.php');
INSERT INTO module_watchdog_param VALUES ('wdcollect_logfile', '/usr/local/psa/var/modules/watchdog/log/wdcollect.log');
INSERT INTO module_watchdog_param VALUES ('wdcollect_pidfile', '/usr/local/psa/var/modules/watchdog/run/wdcollect.pid');
